@@ -5,10 +5,10 @@
  *  David Corcoran <corcoran@linuxnet.com>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
- * Copyright (C) 2002-2009
+ * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: ifdhandler.h 5434 2010-12-08 14:13:21Z rousseau $
+ * $Id: ifdhandler.h 6156 2012-01-01 21:02:08Z rousseau $
  */
 
 /**
@@ -426,25 +426,29 @@ port used by each reader.
   So it is something like: <tt>usb:08e6/3437:libusb:001:042</tt> under
   GNU/Linux.
 
-- libhal
+- libudev
 
-  If pcscd is compiled with libhal support instead of libusb (default
-  since pcsc-lite 1.4.100) the string will look like:
+  If pcscd is compiled with libudev support instead of libusb (default
+  since pcsc-lite 1.6.8) the string will look like:
 
   @code
-  printf("usb:%04x/%04x:libhal:%s", idVendor, idProduct, udi)
+  printf("usb:%04x/%04x:libudev:%d:%s", idVendor, idProduct,
+		bInterfaceNumber, devpath);
   @endcode
 
-  udi is the Universal Device Id at the HAL level.
+  bInterfaceNumber is the number of the interface on the device. It is
+  only usefull for devices with more than one CCID interface.
+
+  devpath is the filename of the device on the file system.
 
   So it is something like:
-  <tt>usb:08e6/3437:libhal:/org/freedesktop/Hal/devices/usb_device_8e6_3437_noserial_if0</tt>
+  <tt>usb:08e6/3437:libudev:0:/dev/bus/usb/008/047</tt>
   under GNU/Linux.
 
 - other
 
   If the driver does not understand the <tt>:libusb:</tt> or
-  <tt>:libhal:</tt> scheme or if a new scheme is used, the driver should
+  <tt>:libudev:</tt> scheme or if a new scheme is used, the driver should
   ignore the part it does not understand instead of failing.
 
   The driver shall recognize the <tt>usb:VID/PID</tt> part and, only if
@@ -579,6 +583,8 @@ don't mind loading a new driver for each reader then ignore Lun.
 @param[in] Tag Tag of the desired data value
 - \ref TAG_IFD_ATR
   Return the ATR and its size (implementation is mandatory).
+- \ref TAG_IFD_SLOTNUM
+  Unused/deprecated
 - \ref SCARD_ATTR_ATR_STRING
   Same as \ref TAG_IFD_ATR but this one is not mandatory. It is defined
   in Microsoft PC/SC SCardGetAttrib().
@@ -600,9 +606,22 @@ don't mind loading a new driver for each reader then ignore Lun.
   <tt>Value[0] = 1</tt> indicates the driver supports simultaneous slot
   accesses.
 - \ref TAG_IFD_POLLING_THREAD
-  If the driver provide a polling thread then @p Value is a pointer to this function
+  Unused/deprecated
+- \ref TAG_IFD_POLLING_THREAD_WITH_TIMEOUT
+  If the driver provides a polling thread then @p Value is a pointer to
+  this function. The function prototype is:
+@verbatim
+  RESPONSECODE foo(DWORD Lun, int timeout);
+@endverbatim
 - \ref TAG_IFD_POLLING_THREAD_KILLABLE
-  Tell if the polling thread can be killed (SYS_ThreadCancel()) by pcscd
+  Tell if the polling thread can be killed (pthread_kill()) by pcscd
+- \ref TAG_IFD_STOP_POLLING_THREAD
+  Returns a pointer in @p Value to the function used to stop the polling
+  thread returned by \ref TAG_IFD_POLLING_THREAD_WITH_TIMEOUT. The
+  function prototype is:
+@verbatim
+  RESPONSECODE foo(DWORD Lun);
+@endverbatim
 @param[in,out] Length Length of the desired data value
 @param[out] Value Value of the desired data
 
