@@ -5,10 +5,10 @@
  *  David Corcoran <corcoran@linuxnet.com>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
- * Copyright (C) 2002-2010
+ * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: ifdwrapper.c 5343 2010-10-22 11:52:22Z rousseau $
+ * $Id: ifdwrapper.c 5860 2011-07-09 11:29:52Z rousseau $
  */
 
 /**
@@ -23,7 +23,6 @@
 #include "config.h"
 #include "misc.h"
 #include "pcscd.h"
-#include "ifdhandler.h"
 #include "debuglog.h"
 #include "readerfactory.h"
 #include "ifdwrapper.h"
@@ -48,7 +47,6 @@ LONG IFDSetPTS(READER_CONTEXT * rContext, DWORD dwProtocol, UCHAR ucFlags,
 	UCHAR ucPTS1, UCHAR ucPTS2, UCHAR ucPTS3)
 {
 	RESPONSECODE rv = IFD_SUCCESS;
-	UCHAR ucValue[1];
 
 #ifndef PCSCLITE_STATIC_DRIVER
 	RESPONSECODE(*IFDH_set_protocol_parameters) (DWORD, DWORD, UCHAR,
@@ -69,8 +67,6 @@ LONG IFDSetPTS(READER_CONTEXT * rContext, DWORD dwProtocol, UCHAR ucFlags,
 	 * Error returned by CCID driver is: CCID_Receive Procedure byte conflict
 	 */
 
-	ucValue[0] = rContext->slot;
-
 #ifndef PCSCLITE_STATIC_DRIVER
 	rv = (*IFDH_set_protocol_parameters) (rContext->slot,
 		dwProtocol, ucFlags, ucPTS1, ucPTS2, ucPTS3);
@@ -249,12 +245,7 @@ LONG IFDPowerICC(READER_CONTEXT * rContext, DWORD dwAction,
 	PUCHAR pucAtr, PDWORD pdwAtrLen)
 {
 	RESPONSECODE rv;
-#ifndef PCSCLITE_STATIC_DRIVER
-	short ret;
-	SMARTCARD_EXTENSION sSmartCard;
-#endif
 	DWORD dwStatus;
-	UCHAR ucValue[1];
 	UCHAR dummyAtr[MAX_ATR_SIZE];
 	DWORD dummyAtrLen = sizeof(dummyAtr);
 
@@ -265,9 +256,7 @@ LONG IFDPowerICC(READER_CONTEXT * rContext, DWORD dwAction,
 	/*
 	 * Zero out everything
 	 */
-	rv = IFD_SUCCESS;
 	dwStatus = 0;
-	ucValue[0] = 0;
 
 	if (NULL == pucAtr)
 		pucAtr = dummyAtr;
@@ -290,8 +279,6 @@ LONG IFDPowerICC(READER_CONTEXT * rContext, DWORD dwAction,
 
 #ifndef PCSCLITE_STATIC_DRIVER
 	rv = (*IFDH_power_icc) (rContext->slot, dwAction, pucAtr, pdwAtrLen);
-
-	ret = ATRDecodeAtr(&sSmartCard, pucAtr, *pdwAtrLen);
 #else
 	rv = IFDHPowerICC(rContext->slot, dwAction, pucAtr, pdwAtrLen);
 #endif
@@ -465,7 +452,7 @@ LONG IFDControl(READER_CONTEXT * rContext, DWORD ControlCode,
 	else
 	{
 		Log2(PCSC_LOG_ERROR, "Card not transacted: %ld", rv);
-		Log3(PCSC_LOG_DEBUG, "ControlCode: 0x%.8LX BytesReturned: %ld",
+		Log3(PCSC_LOG_DEBUG, "ControlCode: 0x%.8lX BytesReturned: %ld",
 			ControlCode, *BytesReturned);
 		LogXxd(PCSC_LOG_DEBUG, "TxBuffer ", TxBuffer, TxLength);
 		LogXxd(PCSC_LOG_DEBUG, "RxBuffer ", RxBuffer, *BytesReturned);
