@@ -10,7 +10,7 @@
  * Copyright (C) 2009
  *  Jean-Luc Giraud <jlgiraud@googlemail.com>
  *
- * $Id: readerfactory.c 5992 2011-10-02 15:42:35Z rousseau $
+ * $Id: readerfactory.c 6129 2011-12-05 13:57:11Z rousseau $
  */
 
 /**
@@ -498,6 +498,7 @@ LONG RFRemoveReader(const char *readerName, int port)
 		{
 			(void)pthread_mutex_destroy(sContext->mMutex);
 			free(sContext->mMutex);
+			sContext->mMutex = NULL;
 			free(sContext->library);
 			free(sContext->device);
 			free(sContext->pMutex);
@@ -513,9 +514,9 @@ LONG RFRemoveReader(const char *readerName, int port)
 			sContext->pFeeds = NULL;
 		}
 
+		(void)pthread_mutex_destroy(&sContext->powerState_lock);
 		sContext->version = 0;
 		sContext->port = 0;
-		sContext->mMutex = NULL;
 		sContext->contexts = 0;
 		sContext->slot = 0;
 		sContext->hLockId = 0;
@@ -538,6 +539,7 @@ LONG RFRemoveReader(const char *readerName, int port)
 			free(currentHandle);
 		}
 		(void)pthread_mutex_unlock(&sContext->handlesList_lock);
+		(void)pthread_mutex_destroy(&sContext->handlesList_lock);
 		list_destroy(&(sContext->handlesList));
 		dwNumReadersContexts -= 1;
 
