@@ -3,10 +3,10 @@
  *
  * Copyright (C) 1999-2004
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2002-2010
+ * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.c 5415 2010-11-23 08:30:14Z rousseau $
+ * $Id: winscard.c 5962 2011-09-24 08:24:34Z rousseau $
  */
 
 /**
@@ -72,8 +72,8 @@
 
 /**
  * @file
- * @brief This handles smartcard reader communications.
- * This is the heart of the M$ smartcard API.
+ * @brief This handles smart card reader communications.
+ * This is the heart of the smart card API.
  *
  * Here are the main server-side functions which execute the requests from the
  * clients.
@@ -190,7 +190,7 @@ LONG SCardEstablishContext(DWORD dwScope, /*@unused@*/ LPCVOID pvReserved1,
 
 	*phContext = (PCSCLITE_SVC_IDENTITY + SYS_RandomInt(1, 65535));
 
-	Log2(PCSC_LOG_DEBUG, "Establishing Context: 0x%X", *phContext);
+	Log2(PCSC_LOG_DEBUG, "Establishing Context: 0x%lX", *phContext);
 
 	return SCARD_S_SUCCESS;
 }
@@ -201,7 +201,7 @@ LONG SCardReleaseContext(SCARDCONTEXT hContext)
 	 * Nothing to do here RPC layer will handle this
 	 */
 
-	Log2(PCSC_LOG_DEBUG, "Releasing Context: 0x%X", hContext);
+	Log2(PCSC_LOG_DEBUG, "Releasing Context: 0x%lX", hContext);
 
 	return SCARD_S_SUCCESS;
 }
@@ -231,7 +231,7 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 			dwShareMode != SCARD_SHARE_DIRECT)
 		return SCARD_E_INVALID_VALUE;
 
-	Log3(PCSC_LOG_DEBUG, "Attempting Connect to %s using protocol: %d",
+	Log3(PCSC_LOG_DEBUG, "Attempting Connect to %s using protocol: %ld",
 		szReader, dwPreferredProtocols);
 
 	rv = RFReaderInfo((LPSTR) szReader, &rContext);
@@ -287,7 +287,7 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 	{
 		if (!(readerState & SCARD_PRESENT))
 		{
-			Log1(PCSC_LOG_ERROR, "Card Not Inserted");
+			Log1(PCSC_LOG_DEBUG, "Card Not Inserted");
 			return SCARD_E_NO_SMARTCARD;
 		}
 
@@ -312,7 +312,7 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 					rContext->readerState->cardAtrLength);
 			}
 			else
-				Log3(PCSC_LOG_ERROR, "Error powering up card: %d 0x%04X",
+				Log3(PCSC_LOG_ERROR, "Error powering up card: %ld 0x%04lX",
 					rv, rv);
 		}
 
@@ -348,23 +348,19 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 			/* the protocol is not yet set (no PPS yet) */
 			if (SCARD_PROTOCOL_UNDEFINED == rContext->readerState->cardProtocol)
 			{
-				UCHAR ucAvailable, ucDefault;
+				int availableProtocols, defaultProtocol;
 				int ret;
 
-				ucDefault = PHGetDefaultProtocol(rContext->readerState->cardAtr,
+				ATRDecodeAtr(&availableProtocols, &defaultProtocol,
+					rContext->readerState->cardAtr,
 					rContext->readerState->cardAtrLength);
-				ucAvailable =
-					PHGetAvailableProtocols(rContext->readerState->cardAtr,
-							rContext->readerState->cardAtrLength);
 
-				/*
-				 * If it is set to ANY let it do any of the protocols
-				 */
+				/* If it is set to ANY let it do any of the protocols */
 				if (dwPreferredProtocols & SCARD_PROTOCOL_ANY_OLD)
 					dwPreferredProtocols = SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1;
 
 				ret = PHSetProtocol(rContext, dwPreferredProtocols,
-					ucAvailable, ucDefault);
+					availableProtocols, defaultProtocol);
 
 				/* keep cardProtocol = SCARD_PROTOCOL_UNDEFINED in case of error  */
 				if (SET_PROTOCOL_PPS_FAILED == ret)
@@ -411,7 +407,7 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 				break;
 
 			default:
-				Log2(PCSC_LOG_ERROR, "Active Protocol: unknown %d",
+				Log2(PCSC_LOG_ERROR, "Active Protocol: unknown %ld",
 					*pdwActiveProtocol);
 		}
 	}
@@ -423,7 +419,7 @@ LONG SCardConnect(/*@unused@*/ SCARDCONTEXT hContext, LPCSTR szReader,
 	 */
 	*phCard = RFCreateReaderHandle(rContext);
 
-	Log2(PCSC_LOG_DEBUG, "hCard Identity: %x", *phCard);
+	Log2(PCSC_LOG_DEBUG, "hCard Identity: %lx", *phCard);
 
 	/*******************************************
 	 *
@@ -562,7 +558,7 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 				rContext->readerState->cardAtr, &dwAtrLen);
 		else
 		{
-			rv = IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
+			IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
 			rv = IFDPowerICC(rContext, IFD_POWER_UP,
 				rContext->readerState->cardAtr, &dwAtrLen);
 		}
@@ -635,21 +631,19 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 			/* the protocol is not yet set (no PPS yet) */
 			if (SCARD_PROTOCOL_UNDEFINED == rContext->readerState->cardProtocol)
 			{
-				UCHAR ucAvailable, ucDefault;
+				int availableProtocols, defaultProtocol;
 				int ret;
 
-				ucDefault = PHGetDefaultProtocol(rContext->readerState->cardAtr,
+				ATRDecodeAtr(&availableProtocols, &defaultProtocol,
+					rContext->readerState->cardAtr,
 					rContext->readerState->cardAtrLength);
-				ucAvailable =
-					PHGetAvailableProtocols(rContext->readerState->cardAtr,
-							rContext->readerState->cardAtrLength);
 
 				/* If it is set to ANY let it do any of the protocols */
 				if (dwPreferredProtocols & SCARD_PROTOCOL_ANY_OLD)
 					dwPreferredProtocols = SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1;
 
 				ret = PHSetProtocol(rContext, dwPreferredProtocols,
-					ucAvailable, ucDefault);
+					availableProtocols, defaultProtocol);
 
 				/* keep cardProtocol = SCARD_PROTOCOL_UNDEFINED in case of error  */
 				if (SET_PROTOCOL_PPS_FAILED == ret)
@@ -696,7 +690,7 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 				break;
 
 			default:
-				Log2(PCSC_LOG_ERROR, "Active Protocol: unknown %d",
+				Log2(PCSC_LOG_ERROR, "Active Protocol: unknown %ld",
 					*pdwActiveProtocol);
 		}
 	}
@@ -803,14 +797,28 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 	}
 
 	/*
-	 * Unlock any blocks on this context
+	 * Try to unlock any blocks on this context
+	 *
+	 * This may fail with SCARD_E_SHARING_VIOLATION if a transaction is
+	 * on going on another card context and dwDisposition == SCARD_LEAVE_CARD.
+	 * We should not stop.
 	 */
 	rv = RFUnlockAllSharing(hCard, rContext);
 	if (rv != SCARD_S_SUCCESS)
-		return rv;
+	{
+		if (rv != SCARD_E_SHARING_VIOLATION)
+		{
+			return rv;
+		}
+		else
+		{
+			if (SCARD_LEAVE_CARD != dwDisposition)
+				return rv;
+		}
+	}
 
 	Log2(PCSC_LOG_DEBUG, "Active Contexts: %d", rContext->contexts);
-	Log2(PCSC_LOG_DEBUG, "dwDisposition: %d", dwDisposition);
+	Log2(PCSC_LOG_DEBUG, "dwDisposition: %ld", dwDisposition);
 
 	if (dwDisposition == SCARD_RESET_CARD ||
 		dwDisposition == SCARD_UNPOWER_CARD)
@@ -832,7 +840,7 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 				rContext->readerState->cardAtr, &dwAtrLen);
 		else
 		{
-			rv = IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
+			IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
 
 #ifdef DISABLE_AUTO_POWER_ON
 			rContext->powerState = POWER_STATE_UNPOWERED;
@@ -963,7 +971,9 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 		DWORD dwGetSize;
 
 		(void)pthread_mutex_lock(&rContext->powerState_lock);
-		if (POWER_STATE_INUSE == rContext->powerState)
+		/* Switch to POWER_STATE_GRACE_PERIOD unless the card was not
+		 * powered */
+		if (POWER_STATE_POWERED <= rContext->powerState)
 		{
 #ifdef DISABLE_AUTO_POWER_ON
 			if (SCARD_RESET_CARD == dwDisposition)
@@ -976,6 +986,7 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 			Log1(PCSC_LOG_DEBUG, "powerState: POWER_STATE_GRACE_PERIOD");
 #endif
 		}
+
 		(void)pthread_mutex_unlock(&rContext->powerState_lock);
 
 		/* ask to stop the "polling" thread so it can be restarted using
@@ -1037,7 +1048,7 @@ LONG SCardBeginTransaction(SCARDHANDLE hCard)
 	if (SCARD_E_SHARING_VIOLATION == rv)
 		(void)SYS_USleep(PCSCLITE_LOCK_POLL_RATE);
 
-	Log2(PCSC_LOG_DEBUG, "Status: 0x%08X", rv);
+	Log2(PCSC_LOG_DEBUG, "Status: 0x%08lX", rv);
 
 	return rv;
 }
@@ -1089,7 +1100,7 @@ LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition)
 				rContext->readerState->cardAtr, &dwAtrLen);
 		else
 		{
-			rv = IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
+			IFDPowerICC(rContext, IFD_POWER_DOWN, NULL, NULL);
 			rv = IFDPowerICC(rContext, IFD_POWER_UP,
 				rContext->readerState->cardAtr, &dwAtrLen);
 		}
@@ -1174,7 +1185,7 @@ LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition)
 	 */
 	(void)RFUnlockSharing(hCard, rContext);
 
-	Log2(PCSC_LOG_DEBUG, "Status: 0x%08X", rv);
+	Log2(PCSC_LOG_DEBUG, "Status: 0x%08lX", rv);
 
 	return rv;
 }
@@ -1210,12 +1221,6 @@ LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderNames,
 	if (rv != SCARD_S_SUCCESS)
 		return rv;
 
-	/*
-	 * Cannot find the hCard in this context
-	 */
-	if (rv != SCARD_S_SUCCESS)
-		return rv;
-
 	if (rContext->readerState->cardAtrLength > MAX_ATR_SIZE)
 		return SCARD_F_INTERNAL_ERROR;
 
@@ -1531,7 +1536,7 @@ LONG SCardTransmit(SCARDHANDLE hCard, const SCARD_IO_REQUEST *pioSendPci,
 	sRecvPci.Length = pioRecvPci->cbPciLength;
 
 	/* the protocol number is decoded a few lines above */
-	Log2(PCSC_LOG_DEBUG, "Send Protocol: T=%d", sSendPci.Protocol);
+	Log2(PCSC_LOG_DEBUG, "Send Protocol: T=%ld", sSendPci.Protocol);
 
 	tempRxLength = dwRxLength;
 
